Reduces the sampling rate of an EDA signal by first applying an anti-aliasing lowpass filter at half the target sampling rate, then decimating the signal.
Value
A new PhysioExperiment with the downsampled
signal in the "raw" assay and the sampling rate set to the actual
achieved rate. Events are preserved. Downsampling parameters are stored in
metadata(x)$eda_downsample (a list with original_sr,
target_sr, factor, original_n_time, and
new_n_time).
References
Boucsein, W. (2012). Electrodermal Activity. 2nd ed. Springer. doi:10.1007/978-1-4614-1126-0
See also
edaFilter for frequency-domain filtering,
edaArtifact for artifact detection and correction